==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/bg/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Потребител е отменил заявка за елемент в уебсайта',
    'a_user_requested' => 'Потребител е направил заявка за елемент в уебсайта',
    'accessory_name' => 'Име на аксесоар:',
    'additional_notes' => 'Допълнителни бележки:',
    'admin_has_created' => 'Администратор е създал акаунт за вас на :web website.',
    'asset' => 'Актив:',
    'asset_name' => 'Име на актив:',
    'asset_requested' => 'Заявка за актив',
    'asset_tag' => 'Етикет на актив:',
    'assigned_to' => 'Възложени на',
    'best_regards' => 'С най-добри пожелания.',
    'canceled' => 'Отменено:',
    'checkin_date' => 'Дата на вписване:',
    'checkout_date' => 'Дата на отписване:',
    'click_to_confirm' => 'Моля кликнете на следния линк за да потвърдите вашия :web account:',
    'click_on_the_link_accessory' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили аксесоара.',
    'click_on_the_link_asset' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили актива.',
    'Confirm_Asset_Checkin' => 'Потвърждение при връщане на актив',
    'Confirm_Accessory_Checkin' => 'Потвърждение при връщане на аксесоар',
    'Confirm_accessory_delivery' => 'Потвърждение при доставка на аксесоар',
    'Confirm_license_delivery' => 'Потвърждение при доставка на лиценз',
    'Confirm_asset_delivery' => 'Потвърждение при доставка на актив',
    'Confirm_consumable_delivery' => 'Потвърждение при доставка на консуматив',
    'current_QTY' => 'Текуща наличност',
    'Days' => 'Дни',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Очаквана дата на вписване',
    'expires' => 'Изтича',
    'Expiring_Assets_Report' => 'Доклад за изтичащи активи.',
    'Expiring_Licenses_Report' => 'Доклад за изтичащи лицензи.',
    'hello' => 'Здравейте',
    'hi' => 'Здравейте',
    'i_have_read' => 'Прочетох и се съгласих с условията за ползване, и получих този артикул.',
    'item' => 'Артикул:',
    'Item_Request_Canceled' => 'Заявка за артикул отменена',
    'Item_Requested' => 'Артикул заявен',
    'link_to_update_password' => 'Моля щракенете върху следния линк за да обновите своята :web password:',
    'login_first_admin' => 'Влезте в своята Snipe-IT инсталация използвайки данните по-долу:',
    'login' => 'Вход:',
    'Low_Inventory_Report' => 'Доклад за нисък запас',
    'min_QTY' => 'Минимално количество',
    'name' => 'Име',
    'new_item_checked' => 'Нов артикул беше изписан под вашете име, детайлите са отдолу.',
    'password' => 'Парола:',
    'password_reset' => 'Нулиране на паролата',

    'read_the_terms' => 'Моля прочетете условията по-долу.',
    'read_the_terms_and_click' => 'Моля прочетете условията за ползване по-долу и щракнете върху връзката в дъното, за да потвърдите че сте прочели и се съгласявате с условията на употреба и сте получили актива.',
    'requested' => 'Изискан:',
    'reset_link' => 'Вашата връзка за повторно задаване на паролата',
    'reset_password' => 'Щракнете тук, за да нулирате паролата си:',
    'serial' => 'Лицензен номер',
    'supplier' => 'Доставчик',
    'tag' => 'Етикет',
    'test_email' => 'Тест Email от Snipe-IT',
    'test_mail_text' => 'Това е тест от Snipe-IT система за управление на активи. Ако сте получили това, email-а работи :)',
    'the_following_item' => 'Следният артикул беше вписан:',
    'low_inventory_alert' => 'Има :count артикул, който е под минималния праг за наличност или скоро ще се изчерпа.| Има :count артикула, които са под минималния праг за наличност или скоро ще се изчерпат.',
    'assets_warrantee_alert' => 'Има :count актив с гаранция, която ще изтече в следващите :threshold дни.|Има :count активa с гаранция, която ще изтече в следващите :threshold дни.',
    'license_expiring_alert' => 'Има :count лиценз, който изтича в следващите :threshold дни.|Има :count лиценза, които изтичат в следващите :threshold дни.',
    'to_reset' => 'За да нулирате вашата :web password, попълнете този формуляр:',
    'type' => 'Вид',
    'upcoming-audits' => 'Има :count актив, който подлежи на одит в следващите :threshold дни.|Има :count активи, които подлежат на отид през следващите :threshold дни.',
    'user' => 'Потребител',
    'username' => 'Потребителско име',
    'welcome' => 'Добре дошли, :name',
    'welcome_to' => 'Добре дошли: уеб!',
    'your_credentials' => 'Вашите идентификационни данни за Snipe-IT',
    'Accessory_Checkin_Notification' => 'Аксесоарат е вписан',
    'Asset_Checkin_Notification' => 'Актива е вписан',
    'License_Checkin_Notification' => 'Лиценза е вписан',
    'Expected_Checkin_Report' => 'Очакван рапорт за вписване на актив',
    'Expected_Checkin_Notification' => 'Напомняне: :name крайната дата за вписване наближава',
    'Expected_Checkin_Date' => 'Наближава срока за връщане на актив който е заведен на Вас, трябва да се върна на :date',
    'your_assets' => 'Преглед на вашите активи'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/bg/mail.php <==
<?php

return [
    'a_user_canceled' => 'Потребител е отменил заявка за елемент в уебсайта',
    'a_user_requested' => 'Потребител е направил заявка за елемент в уебсайта',
    'accessory_name' => 'Име на аксесоар:',
    'additional_notes' => 'Допълнителни бележки:',
    'admin_has_created' => 'Администратор е създал акаунт за вас на :web website.',
    'asset' => 'Актив:',
    'asset_name' => 'Име на актив:',
    'asset_requested' => 'Заявка за актив',
    'asset_tag' => 'Етикет на актив',
    'assigned_to' => 'Възложени на',
    'best_regards' => 'С най-добри пожелания.',
    'canceled' => 'Отменено:',
    'checkin_date' => 'Дата на вписване:',
    'checkout_date' => 'Дата на отписване:',
    'click_to_confirm' => 'Моля кликнете на следния линк за да потвърдите вашия :web account:',
    'click_on_the_link_accessory' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили аксесоара.',
    'click_on_the_link_asset' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили актива.',
    'Confirm_Asset_Checkin' => 'Потвърждение при връщане на актив',
    'Confirm_Accessory_Checkin' => 'Потвърждение при връщане на аксесоар',
    'Confirm_accessory_delivery' => 'Потвърждение при доставка на аксесоар',
    'Confirm_license_delivery' => 'Потвърждение при доставка на лиценз',
    'Confirm_asset_delivery' => 'Потвърждение при доставка на актив',
    'Confirm_consumable_delivery' => 'Потвърждение при доставка на консуматив',
    'current_QTY' => 'Текуща наличност',
    'Days' => 'Дни',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Очаквана дата на вписване',
    'expires' => 'Изтича',
    'Expiring_Assets_Report' => 'Доклад за изтичащи активи.',
    'Expiring_Licenses_Report' => 'Доклад за изтичащи лицензи.',
    'hello' => 'Здравейте',
    'hi' => 'Здравейте',
    'i_have_read' => 'Прочетох и се съгласих с условията за ползване, и получих този артикул.',
    'item' => 'Артикул:',
    'Item_Request_Canceled' => 'Заявка за артикул отменена',
    'Item_Requested' => 'Артикул заявен',
    'link_to_update_password' => 'Моля щракенете върху следния линк за да обновите своята :web password:',
    'login_first_admin' => 'Влезте в своята Snipe-IT инсталация използвайки данните по-долу:',
    'login' => 'Вход:',
    'Low_Inventory_Report' => 'Доклад за нисък запас',
    'min_QTY' => 'Минимално количество',
    'name' => 'Име',
    'new_item_checked' => 'Нов артикул беше изписан под вашете име, детайлите са отдолу.',
    'password' => 'Парола:',
    'password_reset' => 'Нулиране на паролата',

    'read_the_terms' => 'Моля прочетете условията по-долу.',
    'read_the_terms_and_click' => 'Моля прочетете условията за ползване по-долу и щракнете върху връзката в дъното, за да потвърдите че сте прочели и се съгласявате с условията на употреба и сте получили актива.',
    'requested' => 'Изискан:',
    'reset_link' => 'Вашата връзка за повторно задаване на паролата',
    'reset_password' => 'Щракнете тук, за да нулирате паролата си:',
    'serial' => 'Лицензен номер',
    'supplier' => 'Доставчик',
    'tag' => 'Етикет',
    'test_email' => 'Тест Email от Snipe-IT',
    'test_mail_text' => 'Това е тест от Snipe-IT система за управление на активи. Ако сте получили това, email-а работи :)',
    'the_following_item' => 'Следният артикул беше вписан:',
    'low_inventory_alert' => 'Има :count артикул, който е под минималния праг за наличност или скоро ще се изчерпа.| Има :count артикула, които са под минималния праг за наличност или скоро ще се изчерпат.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Има :count лиценз, който изтича в следващите :threshold дни.|Има :count лиценза, които изтичат в следващите :threshold дни.',
    'to_reset' => 'За да нулирате вашата :web password, попълнете този формуляр:',
    'type' => 'Вид',
    'upcoming-audits' => 'Има :count актив, който подлежи на одит в следващите :threshold дни.|Има :count активи, които подлежат на отид през следващите :threshold дни.',
    'user' => 'Потребител',
    'username' => 'Потребителско име',
    'welcome' => 'Добре дошли, :name',
    'welcome_to' => 'Добре дошли: уеб!',
    'your_credentials' => 'Вашите идентификационни данни за Snipe-IT',
    'Accessory_Checkin_Notification' => 'Аксесоарат е вписан',
    'Asset_Checkin_Notification' => 'Актива е вписан',
    'License_Checkin_Notification' => 'Лиценза е вписан',
    'Expected_Checkin_Report' => 'Очакван рапорт за вписване на актив',
    'Expected_Checkin_Notification' => 'Напомняне: :name крайната дата за вписване наближава',
    'Expected_Checkin_Date' => 'Наближава срока за връщане на актив който е заведен на Вас, трябва да се върна на :date',
    'your_assets' => 'Преглед на вашите активи',
];
